@@ -1,3 +1,4 @@
+use clap::CommandFactory;
 use clap_complete::{generate_to, shells::*};
 use clap_mangen::Man;
 use std::fs::File;
@@ -9,7 +10,7 @@ include!("src/cli.rs");
 fn main() -> Result<(), Error> {
     let outdir = "completions";
     let app_name = "dust";
-    let mut cmd = build_cli();
+    let mut cmd = Cli::command();
 
     generate_to(Bash, &mut cmd, app_name, outdir)?;
     generate_to(Zsh, &mut cmd, app_name, outdir)?;
