@@ -304,9 +304,10 @@ fn handle_error_and_retry(failed: &Error, dir: &Path, walk_data: &WalkData) -> b
             editable_error.file_not_found.insert(failed.to_string());
         }
         std::io::ErrorKind::Interrupted => {
-            let mut editable_error = walk_data.errors.lock().unwrap();
             editable_error.interrupted_error += 1;
-            if editable_error.interrupted_error > 3 {
+            // This does happen on some systems. It was set to 3 but sometimes dust runs would exceed this
+            // However, if there is no limit this results in infinite retrys and dust never finishes
+            if editable_error.interrupted_error > 999 {
                 panic!("Multiple Interrupted Errors occurred while scanning filesystem. Aborting");
             } else {
                 return true;
