@@ -62,6 +62,14 @@ pub fn test_d_flag_works() {
     assert!(!output.contains("hello_file"));
 }
 
+#[test]
+pub fn test_d0_works_on_multiple() {
+    // We should see the top level directory but not the sub dirs / files:
+    let output = build_command(vec!["-d", "0", "tests/test_dir/", "tests/test_dir2"]);
+    assert!(output.contains("test_dir "));
+    assert!(output.contains("test_dir2"));
+}
+
 #[test]
 pub fn test_threads_flag_works() {
     let output = build_command(vec!["-T", "1", "tests/test_dir/"]);
@@ -99,7 +107,9 @@ pub fn test_ignore_all_in_file() {
 #[test]
 pub fn test_with_bad_param() {
     let mut cmd = Command::cargo_bin("dust").unwrap();
-    let result = cmd.arg("bad_place").unwrap();
+    cmd.arg("-P").arg("bad_place");
+    let output_error = cmd.unwrap_err();
+    let result = output_error.as_output().unwrap();
     let stderr = str::from_utf8(&result.stderr).unwrap();
     assert!(stderr.contains("No such file or directory"));
 }
